==> humhub-1.17.4.zip: humhub-1.17.4/protected/humhub/messages/cs/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => '<strong>Potvrdit</strong> akci',
    '<strong>Latest</strong> updates' => '<strong>Nejnovější</strong> události',
    '<strong>Mail</strong> summary' => '<strong>Mailové</strong> shrnutí',
    'Actions' => 'Akce',
    'Add:' => 'Přidat:',
    'Administration' => 'Administrace',
    'All' => 'Vše',
    'Allow' => 'Povolit',
    'Allow content from external source' => 'Povolit obsah z externího zdroje',
    'Always allow content from this provider!' => 'Povolit obsah od tohoto poskytovatele!',
    'An error occurred while handling your last action. (Handler not found).' => 'Při manipulaci s vaší poslední akcí došlo k chybě. (Handler nebyl nalezen).',
    'An unexpected error occurred while loading the search result.' => 'Během načítání výsledku vyhledávání došlo k neočekávané chybě.',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Vyskytla se neočekávaná chyba. Pokud chyba stále přetrvává, obraťte se na správce webu.',
    'An unexpected error occurred. Please check whether your file exceeds the allowed upload limit of {maxUploadSize}.' => 'Došlo k neočekávané chybě. Zkontrolujte prosím, zda váš soubor nepřekračuje povolený limit pro nahrávání {maxUploadSize}.',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Došlo k neočekávané chybě serveru. Pokud chyba stále přetrvává, obraťte se na správce webu.',
    'Back' => 'Zpět',
    'Back to dashboard' => 'Zpět na nástěnku',
    'Cancel' => 'Zrušit',
    'Choose language:' => 'Vyberte jazyk:',
    'Close' => 'Zavřít',
    'Collapse' => 'Sbalit',
    'Confirm' => 'Potvrdit',
    'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'Content Addon musí být buď instancí objektu HActiveRecordContent nebo HActiveRecordContentAddon!',
    'Copy to clipboard' => 'Kopírovat do schránky',
    'Could not find content of addon!' => 'Nebylo možné nalézt obsah dolpňku!',
    'Could not find requested page.' => 'Nepodařilo se najít požadovanou stránku.',
    'Default' => 'Výchozí',
    'Delete' => 'Smazat',
    'Deny' => 'Odmítnout',
    'Do you really want to perform this action?' => 'Opravdu chcete tuto akci provést?',
    'Do you want to enable content from \'{urlPrefix}\'?' => 'Chcete povolit obsah z \'{urlPrefix}\'?',
    'Edit' => 'Upravit',
    'Error' => 'Chyba',
    'Error while running your last action (Invalid request method).' => 'Při spuštění poslední akce došlo k chybě (metoda neplatného požadavku).',
    'Error:' => 'Chyba:',
    'Expand' => 'Rozbalit',
    'Export' => 'Export',
    'Info:' => 'Info:',
    'Invalid request method!' => 'Neplatná metoda požadavku!',
    'It looks like you may have taken the wrong turn.' => 'Zdá se, že jste někde špatně odbočili.',
    'Language' => 'Jazyk',
    'Loading...' => 'Načítání....',
    'Login' => 'Přihlásit se',
    'Logo of {appName}' => 'Logo aplikace',
    'Logout' => 'Odhlásit',
    'Menu' => 'Menu',
    'Module is not enabled on this content container!' => 'Modul nebyl nalezen nebo je vypnut!',
    'My Profile' => 'Můj profil',
    'New profile image' => 'Nový profilový obrázek',
    'Next' => 'Další',
    'No error information given.' => 'Nejsou uvedeny žádné informace o chybách.',
    'Oooops...' => 'Jejda...',
    'Open' => 'Otevřít',
    'Please type at least 3 characters' => 'Napište prosím alespoň 3 znaky',
    'Please type at least {count} characters' => 'Zadejte prosím alespoň {count} znaků',
    'Powered by {name}' => 'Powered by {name}',
    'Profile dropdown' => 'Menu profilu',
    'Profile picture of {displayName}' => 'Profilový obrázek',
    'Save' => 'Uložit',
    'Saved' => 'Uloženo',
    'Search' => 'Hledat',
    'Search...' => 'Hledat...',
    'Select Me' => 'Vybrat mě',
    'Settings' => 'Nastavení',
    'Show less' => 'Zobrazit méně',
    'Show more' => 'Zobrazit více',
    'Some files could not be uploaded:' => 'Některé soubory nelze nahrát:',
    'Stop impersonation' => 'Zastavte předstírání jiné identity',
    'Text could not be copied to clipboard' => 'Text se nepodařilo zkopírovat do schránky',
    'Text has been copied to clipboard' => 'Text byl zkopírován do schránky',
    'The date has to be in the past.' => 'Datum musí být v minulosti.',
    'The file has been deleted.' => 'Tento soubor byl vymazán.',
    'The requested resource could not be found.' => 'Požadovaný zdroj nebyl nalezen.',
    'The space has been archived.' => 'Prostor byl archivován.',
    'The space has been unarchived.' => 'Prostor byl zrušen.',
    'Time Zone' => 'Časové pásmo',
    'Toggle comment menu' => 'Přepnout menu komentářů',
    'Toggle panel menu' => 'Přepnout menu panelu',
    'Toggle post menu' => 'Přepnout menu příspěvků',
    'Toggle stream entry menu' => 'Přepnout menu příspěvků',
    'Unsaved changes will be lost. Do you want to proceed?' => 'Neuložené změny budou ztraceny. Chcete pokračovat?',
    'Unsubscribe' => 'Odhlásit odběr',
    'Upload' => 'Nahrát',
    'Upload file' => 'Nahrát soubor',
    'You are not allowed to run this action.' => 'Nemáte povolení spustit tuto akci.',
    'verify your upload_max_filesize and post_max_size php settings.' => 'ověřte upload_max_filesize a post_max_size v nastavení php.',
    '{attribute} has been empty. The system-configured function to fill empty values has returned an invalid value. Please try again or contact your administrator.' => '{attribute} byl prázdný. Funkce nastavená systémem pro vyplnění prázdných hodnot vrátila neplatnou hodnotu. Zkuste to prosím znovu nebo se obraťte na svého správce.',
    '{attribute} must be a string (UUID) or null; {type} given.' => '{attribute} musí být řetězec (UUID) nebo null; {type} zadán.',
    '{attribute} must be an UUID or null. UUID has the format "{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}", where X = [a-fA-F0-9] and both curly brackets and delimiting dashes are optional.' => '{attribute} musí být UUID nebo null. UUID má formát "{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}", kde X = [a-fA-F0-9] a obě složené závorky a oddělovací pomlčky jsou volitelné.',
    '{nFormatted}B' => '{nFormatted}B',
    '{nFormatted}K' => '{nFormatted}K',
    '{nFormatted}M' => '{nFormatted}M',
    'No results' => '',
    'Show all results' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/messages/cs/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => '<strong>Potvrdit</strong> akci',
    '<strong>Latest</strong> updates' => '<strong>Nejnovější</strong> události',
    '<strong>Mail</strong> summary' => '<strong>Mailové</strong> shrnutí',
    'Actions' => 'Akce',
    'Add:' => 'Přidat:',
    'Administration' => 'Administrace',
    'All' => 'Vše',
    'Allow' => 'Povolit',
    'Allow content from external source' => 'Povolit obsah z externího zdroje',
    'Always allow content from this provider!' => 'Povolit obsah od tohoto poskytovatele!',
    'An error occurred while handling your last action. (Handler not found).' => 'Při manipulaci s vaší poslední akcí došlo k chybě. (Handler nebyl nalezen).',
    'An unexpected error occurred while loading the search result.' => 'Během načítání výsledku vyhledávání došlo k neočekávané chybě.',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Vyskytla se neočekávaná chyba. Pokud chyba stále přetrvává, obraťte se na správce webu.',
    'An unexpected error occurred. Please check whether your file exceeds the allowed upload limit of {maxUploadSize}.' => 'Došlo k neočekávané chybě. Zkontrolujte prosím, zda váš soubor nepřekračuje povolený limit pro nahrávání {maxUploadSize}.',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Došlo k neočekávané chybě serveru. Pokud chyba stále přetrvává, obraťte se na správce webu.',
    'Back' => 'Zpět',
    'Back to dashboard' => 'Zpět na nástěnku',
    'Cancel' => 'Zrušit',
    'Choose language:' => 'Vyberte jazyk:',
    'Close' => 'Zavřít',
    'Collapse' => 'Sbalit',
    'Confirm' => 'Potvrdit',
    'Content Addon source must be instance of ContentActiveRecord or ContentAddonActiveRecord!' => 'Content Addon musí být buď instancí objektu ContentActiveRecord nebo ContentAddonActiveRecord!',
    'Copy to clipboard' => 'Kopírovat do schránky',
    'Could not find content of addon!' => 'Nebylo možné nalézt obsah dolpňku!',
    'Could not find requested page.' => 'Nepodařilo se najít požadovanou stránku.',
    'Default' => 'Výchozí',
    'Delete' => 'Smazat',
    'Deny' => 'Odmítnout',
    'Do you really want to perform this action?' => 'Opravdu chcete tuto akci provést?',
    'Do you want to enable content from \'{urlPrefix}\'?' => 'Chcete povolit obsah z \'{urlPrefix}\'?',
    'Edit' => 'Upravit',
    'Enter security code above' => 'Zadejte zabezpečovací kód',
    'Error' => 'Chyba',
    'Error while running your last action (Invalid request method).' => 'Při spuštění poslední akce došlo k chybě (metoda neplatného požadavku).',
    'Error:' => 'Chyba:',
    'Expand' => 'Rozbalit',
    'Export' => 'Export',
    'Info:' => 'Info:',
    'Invalid request method!' => 'Neplatná metoda požadavku!',
    'It looks like you may have taken the wrong turn.' => 'Zdá se, že jste někde špatně odbočili.',
    'Language' => 'Jazyk',
    'Loading...' => 'Načítání....',
    'Login' => 'Přihlásit se',
    'Logo of {appName}' => 'Logo aplikace',
    'Logout' => 'Odhlásit',
    'Menu' => 'Menu',
    'Module is not enabled on this content container!' => 'Modul nebyl nalezen nebo je vypnut!',
    'My Profile' => 'Můj profil',
    'New profile image' => 'Nový profilový obrázek',
    'Next' => 'Další',
    'No error information given.' => 'Nejsou uvedeny žádné informace o chybách.',
    'Oooops...' => 'Jejda...',
    'Open' => 'Otevřít',
    'Please type at least 3 characters' => 'Napište prosím alespoň 3 znaky',
    'Please type at least {count} characters' => 'Zadejte prosím alespoň {count} znaků',
    'Powered by {name}' => 'Powered by {name}',
    'Profile dropdown' => 'Menu profilu',
    'Profile picture of {displayName}' => 'Profilový obrázek',
    'Save' => 'Uložit',
    'Saved' => 'Uloženo',
    'Search' => 'Hledat',
    'Search...' => 'Hledat...',
    'Select Me' => 'Vybrat mě',
    'Settings' => 'Nastavení',
    'Show less' => 'Zobrazit méně',
    'Show more' => 'Zobrazit více',
    'Some files could not be uploaded:' => 'Některé soubory nelze nahrát:',
    'Stop impersonation' => 'Zastavte předstírání jiné identity',
    'Text could not be copied to clipboard' => 'Text se nepodařilo zkopírovat do schránky',
    'Text has been copied to clipboard' => 'Text byl zkopírován do schránky',
    'The date has to be in the past.' => 'Datum musí být v minulosti.',
    'The file has been deleted.' => 'Tento soubor byl vymazán.',
    'The requested resource could not be found.' => 'Požadovaný zdroj nebyl nalezen.',
    'The space has been archived.' => 'Prostor byl archivován.',
    'The space has been unarchived.' => 'Prostor byl zrušen.',
    'Time Zone' => 'Časové pásmo',
    'Toggle comment menu' => 'Přepnout menu komentářů',
    'Toggle panel menu' => 'Přepnout menu panelu',
    'Toggle post menu' => 'Přepnout menu příspěvků',
    'Toggle stream entry menu' => 'Přepnout menu příspěvků',
    'Unsaved changes will be lost. Do you want to proceed?' => 'Neuložené změny budou ztraceny. Chcete pokračovat?',
    'Unsubscribe' => 'Odhlásit odběr',
    'Upload' => 'Nahrát',
    'Upload file' => 'Nahrát soubor',
    'You are not allowed to run this action.' => 'Nemáte povolení spustit tuto akci.',
    'verify your upload_max_filesize and post_max_size php settings.' => 'ověřte upload_max_filesize a post_max_size v nastavení php.',
    '{attribute} has been empty. The system-configured function to fill empty values has returned an invalid value. Please try again or contact your administrator.' => '{attribute} byl prázdný. Funkce nastavená systémem pro vyplnění prázdných hodnot vrátila neplatnou hodnotu. Zkuste to prosím znovu nebo se obraťte na svého správce.',
    '{attribute} must be a string (UUID) or null; {type} given.' => '{attribute} musí být řetězec (UUID) nebo null; {type} zadán.',
    '{attribute} must be an UUID or null. UUID has the format "{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}", where X = [a-fA-F0-9] and both curly brackets and delimiting dashes are optional.' => '{attribute} musí být UUID nebo null. UUID má formát "{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}", kde X = [a-fA-F0-9] a obě složené závorky a oddělovací pomlčky jsou volitelné.',
    '{nFormatted}B' => '{nFormatted}B',
    '{nFormatted}K' => '{nFormatted}K',
    '{nFormatted}M' => '{nFormatted}M',
    'Back to login' => '',
    'I\'m not a robot' => '',
    'No results' => '',
    'Show all results' => '',
    'Switch network' => '',
    'Verified' => '',
    'We couldn\'t verify that you\'re human. Please check the box again.' => '',
];
